#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-EasyProcess%{psuffix}
Version:        1.1
Release:        3.3
Summary:        Python subprocess interface
License:        BSD-2-Clause
URL:            https://github.com/ponty/easyprocess
Source:         https://github.com/ponty/EasyProcess/archive/%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module EasyProcess = %{version}}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module PyVirtualDisplay}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
BuildRequires:  ImageMagick
BuildRequires:  iputils
%endif
%python_subpackages

%description
EasyProcess is a Python subprocess interface.

Features include:
 - layer on top of subprocess module
 - starting and stopping of programs
 - retrieval of standard output/error, return code of programs
 - command can be list or string
 - logging
 - timeout
 - unit-tests
 - cross-platform, development on linux
 - global config file with program aliases
 - unicode support
 - supported python versions: 2.5, 2.6, 2.7, 3.1, 3.2, PyPy

Limitations:
 - shell is not supported
 - pipes are not supported
 - stdout/stderr is set only after the subprocess has finished
 - stop() does not kill whole subprocess tree

%prep
%setup -q -n EasyProcess-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
export LANG=en_US.UTF-8
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/easyprocess
%{python_sitelib}/EasyProcess-%{version}*-info
%endif

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Aug 20 2022 Ben Greiner <code@bnavigator.de>
- Package only supports Python >= 3.7
- Remove linter flake8 and static type checker mypy from build
  requirements: Not used and not necessary during rpm packaging.
- Remove stray build dependency for six
- Remove entrypoint2 build dependency: only required for building
  docs
- Don't catchall in files section
* Wed Aug 10 2022 Otto Hollmann <otto.hollmann@suse.com>
- Fix build dependencies for test flavour
- Update to 1.1:
  * Use popen timeout parameter, remove daemon thread #22
  * use only kill(), remove terminate(), remove kill* parameters #20 #22
  * add py310 support, remove py36
  * fix EASYPROCESS_USE_TEMP_FILES env var usage
  * test: increase timeouts to avoid random fails
  * remove py2
  * add py39 support
  * Add option to force kill process after timeout
* Thu Jul  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3
  * relpace nose with pytest
* Thu Mar 26 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild in order to avoid cycle
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.2.10
  * test and code fixtures
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.2.8
  * enable_stdout_log, enable_stderr_log
  * py38 support
  * remove py34 support
* Tue Nov  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update with spec-cleaner
* Sun Sep 15 2019 John Vandenberg <jayvdb@gmail.com>
- Fix examples to use sys.executable
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.7:
  * Small fixes only
* Fri Apr  5 2019 John Vandenberg <jayvdb@gmail.com>
- Add export LANG=en_US.UTF-8 to fix Leap builds
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.5:
  * Fixes for python 3.7
  * Many utf8 fixes
- Switch to github tarball for tests
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description. Do not put limitations under
  "features".
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 28 2017 toddrme2178@gmail.com
- update to version 0.2.3:
  * no changelog available
- Implement single-spec version
- Fix source URL
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 0.1.9:
  * no changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Feb 17 2013 p.drouand@gmail.com
- Update to version 0.1.6:
  * No changelog available
* Sat Feb 16 2013 p.drouand@gmail.com
- Update to version 0.1.5:
  * No changelog available
* Thu Jan 10 2013 p.drouand@gmail.com
- Initial python3 support package
* Mon Mar 26 2012 saschpe@suse.de
- Initial version
